@@ -3,11 +3,12 @@
 
 import logging
 import os
-import pathlib
 import re
 import sys
 import tempfile
 
+from ruamel.yaml import YAML
+
 from .context import ScaffoldContext
 from .plugin import ScaffoldPluginContext
 from .plugins import load_plugins
@@ -147,19 +148,17 @@ def read_parameter(prompt, context, runtime: ScaffoldRuntime):
                 if matches is None:
                     runtime.write('{RED}[invalid, %s]{END} ' % prompt['validate'])
                     continue
-            if 'load' in prompt:
-                if prompt['load'] == 'yaml':
-                    with open(d, 'r') as fhd:
-                        return yaml.load(fhd, Loader=yaml.FullLoader)
             return convert(d, prompt.get('type', 'str'))
 
 
 def config_cli(args):
     options = {}
     scaffold_file = os.path.expanduser('~/.xscaffold')
+
+    yaml = YAML()
     if os.path.exists(scaffold_file):
         with open(scaffold_file, 'r') as fhd:
-            options = yaml.load(fhd, Loader=yaml.FullLoader)
+            options = yaml.load(fhd)
 
     if args.action == 'save':
         options['url'] = args.url
@@ -231,6 +230,8 @@ def execute_scaffold(context: ScaffoldContext, options, runtime: ScaffoldRuntime
     tempdir = options.get('temp', tempfile.gettempdir())
     package = options['package']
 
+    yaml = YAML()
+
     name = options.get('name', 'xscaffold')
 
     if os.path.exists(package):
@@ -247,7 +248,7 @@ def execute_scaffold(context: ScaffoldContext, options, runtime: ScaffoldRuntime
 
     if scaffold_file is not None:
         with open(scaffold_file, 'r') as fhd:
-            config = yaml.load(fhd, Loader=yaml.FullLoader)
+            config = yaml.load(fhd)
     else:
         config = {
             'steps': options.get('steps', [{ 'fetch': {} }])
