@@ -2,7 +2,7 @@ from x_scaffold.steps import ScaffoldStep
 from github import Github, Repository, PullRequest
 
 import os
-import yaml
+from ruamel.yaml import YAML
 
 from ..plugin import ScaffoldPluginContext
 from ..context import ScaffoldContext
@@ -27,8 +27,9 @@ def fetch_token(options, context):
     host = options.get('host', 'github.com')
     gh_hosts = os.path.expanduser('~/.config/gh/hosts.yml')
     if os.path.exists(gh_hosts):
+        yaml = YAML()
         with open(gh_hosts, 'r') as f:
-            gh_hosts = yaml.load(f, Loader=yaml.FullLoader)
+            gh_hosts = yaml.load(f)
         if host in gh_hosts:
             return gh_hosts[host]['oauth_token']
     
